#[repr(u64)]pub enum DevFlags {
FeatureReportsNumbered = 1,
OutputReportsNumbered = 2,
InputReportsNumbered = 4,
}Expand description
Each of these flags defines whether a given report-type uses numbered reports. If numbered reports are used for a type, all messages from the kernel already have the report-number as prefix. Otherwise, no prefix is added by the kernel. For messages sent by user-space to the kernel, you must adjust the prefixes according to these flags.
Variants